from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Composition
import win32more.Microsoft.UI.Composition.Diagnostics
class CompositionDebugHeatMaps(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Composition.Diagnostics.ICompositionDebugHeatMaps
    _classid_ = 'Microsoft.UI.Composition.Diagnostics.CompositionDebugHeatMaps'
    @winrt_mixinmethod
    def Hide(self: win32more.Microsoft.UI.Composition.Diagnostics.ICompositionDebugHeatMaps, subtree: win32more.Microsoft.UI.Composition.Visual) -> Void: ...
    @winrt_mixinmethod
    def ShowRedraw(self: win32more.Microsoft.UI.Composition.Diagnostics.ICompositionDebugHeatMaps, subtree: win32more.Microsoft.UI.Composition.Visual) -> Void: ...
    @winrt_mixinmethod
    def ShowMemoryUsage(self: win32more.Microsoft.UI.Composition.Diagnostics.ICompositionDebugHeatMaps, subtree: win32more.Microsoft.UI.Composition.Visual) -> Void: ...
    @winrt_mixinmethod
    def ShowOverdraw(self: win32more.Microsoft.UI.Composition.Diagnostics.ICompositionDebugHeatMaps, subtree: win32more.Microsoft.UI.Composition.Visual, contentKinds: win32more.Microsoft.UI.Composition.Diagnostics.CompositionDebugOverdrawContentKinds) -> Void: ...
class CompositionDebugOverdrawContentKinds(Enum, UInt32):
    None_ = 0
    OffscreenRendered = 1
    Colors = 2
    Effects = 4
    Shadows = 8
    Lights = 16
    Surfaces = 32
    SwapChains = 64
    All = 4294967295
class CompositionDebugSettings(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Composition.Diagnostics.ICompositionDebugSettings
    _classid_ = 'Microsoft.UI.Composition.Diagnostics.CompositionDebugSettings'
    @winrt_mixinmethod
    def get_HeatMaps(self: win32more.Microsoft.UI.Composition.Diagnostics.ICompositionDebugSettings) -> win32more.Microsoft.UI.Composition.Diagnostics.CompositionDebugHeatMaps: ...
    @winrt_classmethod
    def TryGetSettings(cls: win32more.Microsoft.UI.Composition.Diagnostics.ICompositionDebugSettingsStatics, compositor: win32more.Microsoft.UI.Composition.Compositor) -> win32more.Microsoft.UI.Composition.Diagnostics.CompositionDebugSettings: ...
    HeatMaps = property(get_HeatMaps, None)
class ICompositionDebugHeatMaps(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Composition.Diagnostics.ICompositionDebugHeatMaps'
    _iid_ = Guid('{815016b8-f645-5c55-87b5-fe2167282b6f}')
    @winrt_commethod(6)
    def Hide(self, subtree: win32more.Microsoft.UI.Composition.Visual) -> Void: ...
    @winrt_commethod(7)
    def ShowMemoryUsage(self, subtree: win32more.Microsoft.UI.Composition.Visual) -> Void: ...
    @winrt_commethod(8)
    def ShowOverdraw(self, subtree: win32more.Microsoft.UI.Composition.Visual, contentKinds: win32more.Microsoft.UI.Composition.Diagnostics.CompositionDebugOverdrawContentKinds) -> Void: ...
    @winrt_commethod(9)
    def ShowRedraw(self, subtree: win32more.Microsoft.UI.Composition.Visual) -> Void: ...
class ICompositionDebugSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Composition.Diagnostics.ICompositionDebugSettings'
    _iid_ = Guid('{f4c0c0f6-7f5f-5014-a0d6-c8c7eeecace6}')
    @winrt_commethod(6)
    def get_HeatMaps(self) -> win32more.Microsoft.UI.Composition.Diagnostics.CompositionDebugHeatMaps: ...
    HeatMaps = property(get_HeatMaps, None)
class ICompositionDebugSettingsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Composition.Diagnostics.ICompositionDebugSettingsStatics'
    _iid_ = Guid('{b56f8aab-2b8c-51aa-b974-10e5c517f50e}')
    @winrt_commethod(6)
    def TryGetSettings(self, compositor: win32more.Microsoft.UI.Composition.Compositor) -> win32more.Microsoft.UI.Composition.Diagnostics.CompositionDebugSettings: ...


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.Windows.ApplicationModel.Resources
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
class IKnownResourceQualifierNameStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IKnownResourceQualifierNameStatics'
    _iid_ = Guid('{dd6cdedc-559b-50c8-ac53-82fe21f915f3}')
    @winrt_commethod(6)
    def get_Contrast(self) -> hstr: ...
    @winrt_commethod(7)
    def get_Custom(self) -> hstr: ...
    @winrt_commethod(8)
    def get_DeviceFamily(self) -> hstr: ...
    @winrt_commethod(9)
    def get_HomeRegion(self) -> hstr: ...
    @winrt_commethod(10)
    def get_Language(self) -> hstr: ...
    @winrt_commethod(11)
    def get_LayoutDirection(self) -> hstr: ...
    @winrt_commethod(12)
    def get_Scale(self) -> hstr: ...
    @winrt_commethod(13)
    def get_TargetSize(self) -> hstr: ...
    @winrt_commethod(14)
    def get_Theme(self) -> hstr: ...
    Contrast = property(get_Contrast, None)
    Custom = property(get_Custom, None)
    DeviceFamily = property(get_DeviceFamily, None)
    HomeRegion = property(get_HomeRegion, None)
    Language = property(get_Language, None)
    LayoutDirection = property(get_LayoutDirection, None)
    Scale = property(get_Scale, None)
    TargetSize = property(get_TargetSize, None)
    Theme = property(get_Theme, None)
class IResourceCandidate(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceCandidate'
    _iid_ = Guid('{6c54bc0c-ef1e-57b8-b478-34fece737356}')
    @winrt_commethod(6)
    def get_ValueAsString(self) -> hstr: ...
    @winrt_commethod(7)
    def get_ValueAsBytes(self) -> ReceiveArray[Byte]: ...
    @winrt_commethod(8)
    def get_Kind(self) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidateKind: ...
    @winrt_commethod(9)
    def get_QualifierValues(self) -> win32more.Windows.Foundation.Collections.IMapView[hstr, hstr]: ...
    Kind = property(get_Kind, None)
    QualifierValues = property(get_QualifierValues, None)
    ValueAsBytes = property(get_ValueAsBytes, None)
    ValueAsString = property(get_ValueAsString, None)
class IResourceCandidateFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceCandidateFactory'
    _iid_ = Guid('{bb2b30f8-c19b-5f43-88d9-69ad728a32f4}')
    @winrt_commethod(6)
    def CreateInstance(self, kind: win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidateKind, data: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
    @winrt_commethod(7)
    def CreateInstance2(self, data: PassArray[Byte]) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
class IResourceContext(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceContext'
    _iid_ = Guid('{96fb48dc-f77d-55ff-af12-34861e3d4939}')
    @winrt_commethod(6)
    def get_QualifierValues(self) -> win32more.Windows.Foundation.Collections.IMap[hstr, hstr]: ...
    QualifierValues = property(get_QualifierValues, None)
class IResourceContext2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceContext2'
    _iid_ = Guid('{7a3b1158-798c-5949-969d-03510b9ce6ca}')
class IResourceLoader(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceLoader'
    _iid_ = Guid('{bc3f76bf-da46-54cd-8715-8b8aaf16eaac}')
    @winrt_commethod(6)
    def GetString(self, resourceId: hstr) -> hstr: ...
    @winrt_commethod(7)
    def GetStringForUri(self, resourceUri: win32more.Windows.Foundation.Uri) -> hstr: ...
class IResourceLoaderFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceLoaderFactory'
    _iid_ = Guid('{871f83aa-fb34-50d6-b9b9-2c35f3ffc004}')
    @winrt_commethod(6)
    def CreateInstance(self, fileName: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceLoader: ...
    @winrt_commethod(7)
    def CreateInstance2(self, fileName: hstr, resourceMap: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceLoader: ...
class IResourceLoaderStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceLoaderStatics'
    _iid_ = Guid('{ec9c894a-1466-5f2f-8eee-a70cbd2b51bb}')
    @winrt_commethod(6)
    def GetDefaultResourceFilePath(self) -> hstr: ...
class IResourceManager(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceManager'
    _iid_ = Guid('{ac2291ef-81be-5c99-a0ae-bcee0180b8a8}')
    @winrt_commethod(6)
    def get_MainResourceMap(self) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceMap: ...
    @winrt_commethod(7)
    def CreateResourceContext(self) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceContext: ...
    @winrt_commethod(8)
    def add_ResourceNotFound(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceManager, win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceNotFoundEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_ResourceNotFound(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    MainResourceMap = property(get_MainResourceMap, None)
    ResourceNotFound = event(add_ResourceNotFound, remove_ResourceNotFound)
class IResourceManager2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceManager2'
    _iid_ = Guid('{7ec10160-a154-5c42-8268-30e306b1f585}')
class IResourceManagerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceManagerFactory'
    _iid_ = Guid('{d6acf18f-458a-535b-a5c4-ac2dc4e49099}')
    @winrt_commethod(6)
    def CreateInstance(self, fileName: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceManager: ...
class IResourceMap(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceMap'
    _iid_ = Guid('{4abbd9bc-df4e-5c7b-812c-7e7bb0c22377}')
    @winrt_commethod(6)
    def get_ResourceCount(self) -> UInt32: ...
    @winrt_commethod(7)
    def GetSubtree(self, reference: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceMap: ...
    @winrt_commethod(8)
    def TryGetSubtree(self, reference: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceMap: ...
    @winrt_commethod(9)
    def GetValue(self, resource: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
    @winrt_commethod(10)
    def GetValueWithContext(self, resource: hstr, context: win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceContext) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
    @winrt_commethod(11)
    def GetValueByIndex(self, index: UInt32) -> win32more.Windows.Foundation.Collections.IKeyValuePair[hstr, win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate]: ...
    @winrt_commethod(12)
    def GetValueByIndexWithContext(self, index: UInt32, context: win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceContext) -> win32more.Windows.Foundation.Collections.IKeyValuePair[hstr, win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate]: ...
    @winrt_commethod(13)
    def TryGetValue(self, resource: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
    @winrt_commethod(14)
    def TryGetValueWithContext(self, resource: hstr, context: win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceContext) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
    ResourceCount = property(get_ResourceCount, None)
class IResourceNotFoundEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.IResourceNotFoundEventArgs'
    _iid_ = Guid('{64abb08b-e77d-5b26-830f-15941e0e8200}')
    @winrt_commethod(6)
    def get_Context(self) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceContext: ...
    @winrt_commethod(7)
    def get_Name(self) -> hstr: ...
    @winrt_commethod(8)
    def SetResolvedCandidate(self, candidate: win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate) -> Void: ...
    Context = property(get_Context, None)
    Name = property(get_Name, None)
class _KnownResourceQualifierName_Meta_(ComPtr.__class__):
    pass
class KnownResourceQualifierName(ComPtr, metaclass=_KnownResourceQualifierName_Meta_):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.KnownResourceQualifierName'
    @winrt_classmethod
    def get_Contrast(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IKnownResourceQualifierNameStatics) -> hstr: ...
    @winrt_classmethod
    def get_Custom(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IKnownResourceQualifierNameStatics) -> hstr: ...
    @winrt_classmethod
    def get_DeviceFamily(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IKnownResourceQualifierNameStatics) -> hstr: ...
    @winrt_classmethod
    def get_HomeRegion(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IKnownResourceQualifierNameStatics) -> hstr: ...
    @winrt_classmethod
    def get_Language(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IKnownResourceQualifierNameStatics) -> hstr: ...
    @winrt_classmethod
    def get_LayoutDirection(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IKnownResourceQualifierNameStatics) -> hstr: ...
    @winrt_classmethod
    def get_Scale(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IKnownResourceQualifierNameStatics) -> hstr: ...
    @winrt_classmethod
    def get_TargetSize(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IKnownResourceQualifierNameStatics) -> hstr: ...
    @winrt_classmethod
    def get_Theme(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IKnownResourceQualifierNameStatics) -> hstr: ...
    _KnownResourceQualifierName_Meta_.Contrast = property(get_Contrast, None)
    _KnownResourceQualifierName_Meta_.Custom = property(get_Custom, None)
    _KnownResourceQualifierName_Meta_.DeviceFamily = property(get_DeviceFamily, None)
    _KnownResourceQualifierName_Meta_.HomeRegion = property(get_HomeRegion, None)
    _KnownResourceQualifierName_Meta_.Language = property(get_Language, None)
    _KnownResourceQualifierName_Meta_.LayoutDirection = property(get_LayoutDirection, None)
    _KnownResourceQualifierName_Meta_.Scale = property(get_Scale, None)
    _KnownResourceQualifierName_Meta_.TargetSize = property(get_TargetSize, None)
    _KnownResourceQualifierName_Meta_.Theme = property(get_Theme, None)
MrtCoreContract: UInt32 = 65536
class ResourceCandidate(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceCandidate
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate.CreateInstance2(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance2(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceCandidateFactory, data: PassArray[Byte]) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceCandidateFactory, kind: win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidateKind, data: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
    @winrt_mixinmethod
    def get_ValueAsString(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceCandidate) -> hstr: ...
    @winrt_mixinmethod
    def get_ValueAsBytes(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceCandidate) -> ReceiveArray[Byte]: ...
    @winrt_mixinmethod
    def get_Kind(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceCandidate) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidateKind: ...
    @winrt_mixinmethod
    def get_QualifierValues(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceCandidate) -> win32more.Windows.Foundation.Collections.IMapView[hstr, hstr]: ...
    Kind = property(get_Kind, None)
    QualifierValues = property(get_QualifierValues, None)
    ValueAsBytes = property(get_ValueAsBytes, None)
    ValueAsString = property(get_ValueAsString, None)
class ResourceCandidateKind(Enum, Int32):
    Unknown = 0
    String = 1
    FilePath = 2
    EmbeddedData = 3
class ResourceContext(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceContext
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.ResourceContext'
    @winrt_mixinmethod
    def get_QualifierValues(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceContext) -> win32more.Windows.Foundation.Collections.IMap[hstr, hstr]: ...
    QualifierValues = property(get_QualifierValues, None)
class ResourceLoader(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceLoader
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.ResourceLoader'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceLoader.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceLoader.CreateInstance(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceLoader.CreateInstance2(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_overload
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceLoader: ...
    @CreateInstance.register
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceLoaderFactory, fileName: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceLoader: ...
    @winrt_factorymethod
    def CreateInstance2(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceLoaderFactory, fileName: hstr, resourceMap: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceLoader: ...
    @winrt_mixinmethod
    def GetString(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceLoader, resourceId: hstr) -> hstr: ...
    @winrt_mixinmethod
    def GetStringForUri(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceLoader, resourceUri: win32more.Windows.Foundation.Uri) -> hstr: ...
    @winrt_classmethod
    def GetDefaultResourceFilePath(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceLoaderStatics) -> hstr: ...
class ResourceManager(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceManager
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.ResourceManager'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceManager.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceManager.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_overload
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceManager: ...
    @CreateInstance.register
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceManagerFactory, fileName: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceManager: ...
    @winrt_mixinmethod
    def get_MainResourceMap(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceManager) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceMap: ...
    @winrt_mixinmethod
    def CreateResourceContext(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceManager) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceContext: ...
    @winrt_mixinmethod
    def add_ResourceNotFound(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceManager, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceManager, win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceNotFoundEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ResourceNotFound(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceManager, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    MainResourceMap = property(get_MainResourceMap, None)
    ResourceNotFound = event(add_ResourceNotFound, remove_ResourceNotFound)
class ResourceMap(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceMap
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.ResourceMap'
    @winrt_mixinmethod
    def get_ResourceCount(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceMap) -> UInt32: ...
    @winrt_mixinmethod
    def GetSubtree(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceMap, reference: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceMap: ...
    @winrt_mixinmethod
    def TryGetSubtree(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceMap, reference: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceMap: ...
    @winrt_mixinmethod
    def GetValue(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceMap, resource: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
    @winrt_mixinmethod
    def GetValueWithContext(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceMap, resource: hstr, context: win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceContext) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
    @winrt_mixinmethod
    def GetValueByIndex(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceMap, index: UInt32) -> win32more.Windows.Foundation.Collections.IKeyValuePair[hstr, win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate]: ...
    @winrt_mixinmethod
    def GetValueByIndexWithContext(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceMap, index: UInt32, context: win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceContext) -> win32more.Windows.Foundation.Collections.IKeyValuePair[hstr, win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate]: ...
    @winrt_mixinmethod
    def TryGetValue(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceMap, resource: hstr) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
    @winrt_mixinmethod
    def TryGetValueWithContext(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceMap, resource: hstr, context: win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceContext) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate: ...
    ResourceCount = property(get_ResourceCount, None)
class ResourceNotFoundEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceNotFoundEventArgs
    _classid_ = 'Microsoft.Windows.ApplicationModel.Resources.ResourceNotFoundEventArgs'
    @winrt_mixinmethod
    def get_Context(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceNotFoundEventArgs) -> win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceContext: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceNotFoundEventArgs) -> hstr: ...
    @winrt_mixinmethod
    def SetResolvedCandidate(self: win32more.Microsoft.Windows.ApplicationModel.Resources.IResourceNotFoundEventArgs, candidate: win32more.Microsoft.Windows.ApplicationModel.Resources.ResourceCandidate) -> Void: ...
    Context = property(get_Context, None)
    Name = property(get_Name, None)


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Xaml.Automation.Text
class TextPatternRangeEndpoint(Enum, Int32):
    Start = 0
    End = 1
class TextUnit(Enum, Int32):
    Character = 0
    Format = 1
    Word = 2
    Line = 3
    Paragraph = 4
    Page = 5
    Document = 6


make_ready(__name__)



from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Printing
import win32more.Windows.Foundation
import win32more.Windows.Graphics.Printing
class AddPagesEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Printing.IAddPagesEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Printing.AddPagesEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Printing.AddPagesEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Printing.AddPagesEventArgs: ...
    @winrt_mixinmethod
    def get_PrintTaskOptions(self: win32more.Microsoft.UI.Xaml.Printing.IAddPagesEventArgs) -> win32more.Windows.Graphics.Printing.PrintTaskOptions: ...
    PrintTaskOptions = property(get_PrintTaskOptions, None)
class AddPagesEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{ed77566a-bd03-5118-b7c3-d9cea64307dd}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Printing.AddPagesEventArgs) -> Void: ...
class GetPreviewPageEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Printing.IGetPreviewPageEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Printing.GetPreviewPageEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Printing.GetPreviewPageEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Printing.GetPreviewPageEventArgs: ...
    @winrt_mixinmethod
    def get_PageNumber(self: win32more.Microsoft.UI.Xaml.Printing.IGetPreviewPageEventArgs) -> Int32: ...
    PageNumber = property(get_PageNumber, None)
class GetPreviewPageEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{1c801689-a018-5574-9109-bcef62176da2}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Printing.GetPreviewPageEventArgs) -> Void: ...
class IAddPagesEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Printing.IAddPagesEventArgs'
    _iid_ = Guid('{a69f3cb3-6b74-5ee8-b034-188098a98c5d}')
    @winrt_commethod(6)
    def get_PrintTaskOptions(self) -> win32more.Windows.Graphics.Printing.PrintTaskOptions: ...
    PrintTaskOptions = property(get_PrintTaskOptions, None)
class IGetPreviewPageEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Printing.IGetPreviewPageEventArgs'
    _iid_ = Guid('{a68fbe17-f577-597f-b3ab-b379447149e6}')
    @winrt_commethod(6)
    def get_PageNumber(self) -> Int32: ...
    PageNumber = property(get_PageNumber, None)
class IPaginateEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Printing.IPaginateEventArgs'
    _iid_ = Guid('{6499c196-11a9-5ef8-91cb-52fb963bf172}')
    @winrt_commethod(6)
    def get_PrintTaskOptions(self) -> win32more.Windows.Graphics.Printing.PrintTaskOptions: ...
    @winrt_commethod(7)
    def get_CurrentPreviewPageNumber(self) -> Int32: ...
    CurrentPreviewPageNumber = property(get_CurrentPreviewPageNumber, None)
    PrintTaskOptions = property(get_PrintTaskOptions, None)
class IPrintDocument(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Printing.IPrintDocument'
    _iid_ = Guid('{1e40f1fc-5d33-5fe9-ba3e-954c0d161524}')
    @winrt_commethod(6)
    def get_DocumentSource(self) -> win32more.Windows.Graphics.Printing.IPrintDocumentSource: ...
    @winrt_commethod(7)
    def add_Paginate(self, handler: win32more.Microsoft.UI.Xaml.Printing.PaginateEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_Paginate(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def add_GetPreviewPage(self, handler: win32more.Microsoft.UI.Xaml.Printing.GetPreviewPageEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_GetPreviewPage(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_AddPages(self, handler: win32more.Microsoft.UI.Xaml.Printing.AddPagesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_AddPages(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(13)
    def AddPage(self, pageVisual: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(14)
    def AddPagesComplete(self) -> Void: ...
    @winrt_commethod(15)
    def SetPreviewPageCount(self, count: Int32, type: win32more.Microsoft.UI.Xaml.Printing.PreviewPageCountType) -> Void: ...
    @winrt_commethod(16)
    def SetPreviewPage(self, pageNumber: Int32, pageVisual: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(17)
    def InvalidatePreview(self) -> Void: ...
    DocumentSource = property(get_DocumentSource, None)
    AddPages = event(add_AddPages, remove_AddPages)
    GetPreviewPage = event(add_GetPreviewPage, remove_GetPreviewPage)
    Paginate = event(add_Paginate, remove_Paginate)
class IPrintDocumentFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Printing.IPrintDocumentFactory'
    _iid_ = Guid('{c4c1bc12-84d1-539c-b416-d7e54c45ab58}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Printing.PrintDocument: ...
class IPrintDocumentStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Printing.IPrintDocumentStatics'
    _iid_ = Guid('{8975e4bc-8fc8-5e8f-a55a-bf71b9a827b7}')
    @winrt_commethod(6)
    def get_DocumentSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DocumentSourceProperty = property(get_DocumentSourceProperty, None)
class PaginateEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Printing.IPaginateEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Printing.PaginateEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Printing.PaginateEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Printing.PaginateEventArgs: ...
    @winrt_mixinmethod
    def get_PrintTaskOptions(self: win32more.Microsoft.UI.Xaml.Printing.IPaginateEventArgs) -> win32more.Windows.Graphics.Printing.PrintTaskOptions: ...
    @winrt_mixinmethod
    def get_CurrentPreviewPageNumber(self: win32more.Microsoft.UI.Xaml.Printing.IPaginateEventArgs) -> Int32: ...
    CurrentPreviewPageNumber = property(get_CurrentPreviewPageNumber, None)
    PrintTaskOptions = property(get_PrintTaskOptions, None)
class PaginateEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{c291876c-343a-5b9b-a36c-8415ba4cd9dd}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Printing.PaginateEventArgs) -> Void: ...
class PreviewPageCountType(Enum, Int32):
    Final = 0
    Intermediate = 1
class _PrintDocument_Meta_(ComPtr.__class__):
    pass
class PrintDocument(ComPtr, metaclass=_PrintDocument_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument
    _classid_ = 'Microsoft.UI.Xaml.Printing.PrintDocument'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Printing.PrintDocument.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Printing.IPrintDocumentFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Printing.PrintDocument: ...
    @winrt_mixinmethod
    def get_DocumentSource(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument) -> win32more.Windows.Graphics.Printing.IPrintDocumentSource: ...
    @winrt_mixinmethod
    def add_Paginate(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument, handler: win32more.Microsoft.UI.Xaml.Printing.PaginateEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Paginate(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_GetPreviewPage(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument, handler: win32more.Microsoft.UI.Xaml.Printing.GetPreviewPageEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_GetPreviewPage(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_AddPages(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument, handler: win32more.Microsoft.UI.Xaml.Printing.AddPagesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AddPages(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def AddPage(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument, pageVisual: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def AddPagesComplete(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument) -> Void: ...
    @winrt_mixinmethod
    def SetPreviewPageCount(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument, count: Int32, type: win32more.Microsoft.UI.Xaml.Printing.PreviewPageCountType) -> Void: ...
    @winrt_mixinmethod
    def SetPreviewPage(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument, pageNumber: Int32, pageVisual: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def InvalidatePreview(self: win32more.Microsoft.UI.Xaml.Printing.IPrintDocument) -> Void: ...
    @winrt_classmethod
    def get_DocumentSourceProperty(cls: win32more.Microsoft.UI.Xaml.Printing.IPrintDocumentStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DocumentSource = property(get_DocumentSource, None)
    _PrintDocument_Meta_.DocumentSourceProperty = property(get_DocumentSourceProperty, None)
    AddPages = event(add_AddPages, remove_AddPages)
    GetPreviewPage = event(add_GetPreviewPage, remove_GetPreviewPage)
    Paginate = event(add_Paginate, remove_Paginate)


make_ready(__name__)
